pub struct ColorGradient { /* private fields */ }Expand description
A class to represent a gradient of colors.
Implementations
Sourceimpl ColorGradient
impl ColorGradient
Sourcepub fn new(
spec: Option<Vec<(f32, &str)>>,
preset: Option<Presets>,
) -> Result<Self>
pub fn new( spec: Option<Vec<(f32, &str)>>, preset: Option<Presets>, ) -> Result<Self>
Instantiate a ColorGradient object.
The spec parameter is an optional list of (f32, String) pairs.
The float value is a percentage ranging [0.0, 1.0] that describes
where the color (the str value) should take place.
See SolidColor::from_string() for supported String values that describe the color.
If spec parameter is not specified, then the optional preset parameter
(which defaults to Presets::MonoChrome) is used instead.
Sourcepub fn get_color_at(&self, position: f32, spread: &Spread) -> SolidColor
pub fn get_color_at(&self, position: f32, spread: &Spread) -> SolidColor
A helper function to get the interpolated color of the gradient at the specified position.
If position is beyond the range [0, 1.0], then the spread parameter is
applied accordingly. See the Spread for more details.