pub struct ConicalGradient {
pub center: LayerOffset,
/* private fields */
}Expand description
A data structure to represent a conical gradient.
Fields
center: LayerOffsetThe center point (Offset) of the gradient (relative to the Layer.offset).
Implementations
Sourceimpl ConicalGradient
impl ConicalGradient
Sourcepub fn new(
colors: ColorGradient,
center: LayerOffset,
angle: Option<f32>,
) -> Self
pub fn new( colors: ColorGradient, center: LayerOffset, angle: Option<f32>, ) -> Self
Creates a conical gradient from colors, center, and
an optional starting angle.
Sourcepub fn get_angle(&self) -> f32
pub fn get_angle(&self) -> f32
The starting angle (in degrees) of the gradient.
A 0 degree angle is at 3 o’clock. This angle increases counter-clockwise.
Sourcepub fn set_angle(&mut self, val: f32)
pub fn set_angle(&mut self, val: f32)
Sets the starting angle in degrees.
Values are normalized into the inclusive range [0.0, 360.0).
Sourcepub fn get_color_at(&self, x: u32, y: u32) -> SolidColor
pub fn get_color_at(&self, x: u32, y: u32) -> SolidColor
A helper function for renderers to get the color at a certain point.
The given x and y values are the coordinate of the pixel in the Layer
(relative to Layer::offset).