pub struct Line {
pub amount: NonZeroI32,
pub height: LineHeight,
}Expand description
A property to implicitly describe the size of the text in a
Typography attribute.
Fields
amount: NonZeroI32The maximum number of lines in the layer.
This value shall not be less than or equal to zero.
height: LineHeightThe height ratio of each line in the layer.
This value shall not be less than or equal to zero.
Implementations