pub struct Mask {
pub size: Option<Size>,
pub offset: LayerOffset,
pub invert: bool,
pub background: Option<Background>,
pub rectangle: Option<Rectangle>,
pub ellipse: Option<Ellipse>,
pub polygon: Option<Polygon>,
pub icon: Option<Icon>,
pub typography: Option<Typography>,
}Fields
size: Option<Size>The mask’s Size.
offset: LayerOffsetThe mask’s LayerOffset.
invert: boolA flag to control the behavior of the mask.
False means only visible pixels are used in the mask. True means only invisible pixels are used in the mask.
background: Option<Background>A background attribute for the mask.
rectangle: Option<Rectangle>A rectangle attribute for the mask.
ellipse: Option<Ellipse>An ellipse attribute for the mask.
polygon: Option<Polygon>An polygon attribute for the mask.
icon: Option<Icon>An icon attribute for the mask.
typography: Option<Typography>A typography attribute for the mask.